
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v5.044.
use strict;
use warnings;

use Module::Build 0.3601;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.3601"
  },
  "configure_requires" => {
    "Module::Build" => "0.3601"
  },
  "dist_abstract" => "a mapping toolkit",
  "dist_author" => [
    "Yan Xueqing <yanxueqing621\@163.com>"
  ],
  "dist_name" => "BioX-Map-CLIS",
  "dist_version" => "0.0.3",
  "license" => "perl",
  "module_name" => "BioX::Map::CLIS",
  "recursive_test_files" => 1,
  "requires" => {
    "Carp" => 0,
    "Cwd" => 0,
    "File::ShareDir" => 0,
    "File::Which" => 0,
    "FindBin" => 0,
    "IO::All" => 0,
    "IPC::Run" => 0,
    "Modern::Perl" => 0,
    "Moo" => 0,
    "MooX::Cmd" => 0,
    "MooX::Options" => 0,
    "Parallel::ForkManager" => 0,
    "Types::Standard" => 0,
    "lib" => 0
  },
  "script_files" => [
    "bin/biox-map"
  ],
  "share_dir" => {
    "dist" => "share"
  },
  "test_requires" => {
    "Data::Dumper" => 0,
    "Test::File::ShareDir" => 0,
    "Test::More" => 0,
    "Test::Pod" => 0,
    "Test::Pod::Coverage" => "1.00"
  }
);


my %fallback_build_requires = (
  "Data::Dumper" => 0,
  "Module::Build" => "0.3601",
  "Test::File::ShareDir" => 0,
  "Test::More" => 0,
  "Test::Pod" => 0,
  "Test::Pod::Coverage" => "1.00"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
